@@ -5,7 +5,7 @@ use warnings;
 package AtteanX::Query::Cache;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.001_04';
+our $VERSION   = '0.002';
 use Moo;
 
 extends 'AtteanX::Endpoint';
@@ -33,10 +33,21 @@ AtteanX::Query::Cache - Experimental prefetching SPARQL query cacher
 
 =head1 DESCRIPTION
 
+This is an alpha release of a system that is able to intercept SPARQL
+queries if deployed in a proxy, and analyze the queries so that the
+query can be evaluated on the proxy. It can look up in a cache on the
+proxy, send parts of the query on to the remote endpoint, use Linked
+Data Fragments when appropriate and so on. The analyzer may also
+decide to prefetch certain data asynchronously.
+
+It is known at present to have insufficient performance for any
+practical use, but is released anyway as an alpha.
+
+
 =head1 BUGS
 
 Please report any bugs to
-L<http://rt.cpan.org/Dist/Display.html?Queue=AtteanX-Query-Cache>.
+L<https://github.com/kjetilk/p5-atteanx-query-cache/issues>.
 
 =head1 SEE ALSO
 
